@@ -51,7 +51,7 @@ pub use args::*;
 use anyhow::{anyhow, bail, Context, Result};
 use config::{locate_template_configs, Config, CONFIG_FILE_NAME};
 use console::style;
-use copy::copy_files_recursively;
+use copy::{copy_files_recursively, LIQUID_SUFFIX};
 use env_logger::fmt::Formatter;
 use fs_err as fs;
 use hooks::{execute_hooks, RhaiHooksContext};
@@ -264,6 +264,7 @@ fn get_source_template_into_temp(
             );
             if let Ok((ref temp_dir, _)) = result {
                 git::remove_history(temp_dir.path())?;
+                strip_liquid_suffixes(temp_dir.path())?;
             };
             result
         }
@@ -276,6 +277,24 @@ fn get_source_template_into_temp(
     }
 }
 
+/// remove .liquid suffixes from git templates for parity with path templates
+fn strip_liquid_suffixes(dir: impl AsRef<Path>) -> Result<()> {
+    for entry in fs::read_dir(dir.as_ref())? {
+        let entry = entry?;
+        let entry_type = entry.file_type()?;
+
+        if entry_type.is_dir() {
+            strip_liquid_suffixes(entry.path())?;
+        } else if entry_type.is_file() {
+            let path = entry.path().to_string_lossy().to_string();
+            if let Some(new_path) = path.clone().strip_suffix(LIQUID_SUFFIX) {
+                fs::rename(path, new_path)?;
+            }
+        }
+    }
+    Ok(())
+}
+
 /// resolve the template location for the actual template to expand
 fn resolve_template_dir(template_base_dir: &TempDir, subfolder: Option<&str>) -> Result<PathBuf> {
     let template_dir = resolve_template_dir_subfolder(template_base_dir.path(), subfolder)?;
@@ -530,7 +549,7 @@ fn expand_template(
         Err(e) => {
             // Don't print the error twice
             if !args.quiet && args.continue_on_error {
-                warn!("{}", e);
+                warn!("{e}");
             }
             if !args.continue_on_error {
                 return Err(e);
